<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Verzia %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je Slobodným Softvérom, ktorého vývoj si žiada značnú dávku času.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Prosím o finančnú &lt;a href=&apos;%1&apos;&gt;podporu&lt;/a&gt; pokračujúceho vývoja %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Vydané pod &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zatvoriť</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O projekte</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Všetko čo chceš o %1 vedieť, bez potreby sa vopred spýtať </translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Je možné, že ťa zaujmú aj moje ostatné aplikácie:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, komfortné YouTube rozhranie</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, prehrávač YouTube muziky</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Prelož %1 do svojho materinského jazyka cez %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licencované pre: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Vlož svoje licenčné detaily</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-mail:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kód:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Prosím licencujte %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Demoverzia expirovala.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Aplikácia bez licencie expiruje za %1 dní.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Zakúpením plnej verzie tiež podporíš vynaložené úsilie pri tvorbe %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Použiť demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Vložiť licenciu</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Zakúpiť licenciu</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Plná verzia ti umožní pridať viac ako %1 skladieb do playlistu a vychutnať si teda muziku bez prerušení.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Zakúpiť na %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Čítať viac</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Interprét</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularita</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Opačné poradie</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Zoradiť podľa</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Čítať viac</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Počet skladieb</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Počet albumov</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Meno</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularita</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Opačné poradie</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Zoradiť podľa</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Naspäť</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Ísť späť</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Vitaj v aplikácii &lt;a href=&apos;%1&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 najprv začlení tvoju hudobnú zbierku.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Použiť kolekciu z iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Použiť %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Zvoľ adresár...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 sa pripojí k webovej službe Last.fm a načíta názvy skupín a albumov v snahe získať adekvátne hudobné informácie a grafické obaly.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Pokiaľ máš obavy vzhľadom na súkromie, môžeš proces prerušiť.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Kde máš svoju hudobnú zbierku?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Zvoľ cestu k svojej hudobnej zbierke.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Nájsť svoju zbierku</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Katalogizácia už práve prebieha</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 začleňuje tvoju hudbonú zbierku.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 používa &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; pre katalogizáciu tvojej hudby.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Potrvá to istý čas s ohľadom na rozsiahlosť zbierky a rýchlosti spojenia.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Počkaj chvíľku prosím</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Sťahujem aktualizáciu...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Pusť sem, pre pridanie do playlistu</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Interpréti</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumy</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Adresáre</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Prehrať</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Prehrať/Pozastaviť</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Zastav hranie po aktuálnej skladbe</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Nasledovná skladba</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Predošlá skladba</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Zvýšiť hlasitosť</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Znížiť hlasitosť</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stlmiť</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Pretočiť vpred</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Pretočiť vzad</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Overenie zlyhalo</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Prihlásenie do %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Používateľské meno:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Heslo:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Registrácia %1 účtu</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Zabudnuté &lt;a href=&apos;%1&gt;používateľské meno&lt;/a&gt; alebo &lt;a href=&apos;%2&apos;&gt;heslo&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Naspäť</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Ísť na predošlé zobrazenie</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Zobraziť informácie o aktuálnej skladbe</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Predošlá</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ísť na predošlú skladbu</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Nasledovná</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Preskočiť na nasledovnú skladbu</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Prehrať</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Spustiť prehrávanie</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Na celú obrazovku</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Odstrániť</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Odstrániť vybrané skladby z playlistu</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Posunúť &amp;Nahor</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Posunúť vybrané skladby v playliste nahor</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Posunúť &amp;Nadol</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Posunúť vybrané skladby v playliste nadol</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončiť</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Maj sa</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Zmeniť adresár zbierky...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Vybrať odlišný adresár hudobnej kolekcie</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Webstránka</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na Internete</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Darovať &amp;príspevok</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Podpor prosím pokračujúci vývoj %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O projekte</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informácie o projekte %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Vyčistiť</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Vyčistiť playlist</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Zamiešať</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Náhodné prehrávanie skladieb</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Opakovať</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Opätovne prehrať prvú pieseň po skončení</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Stlmiť hlasitosť</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplikácia</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Prehrávanie</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Playlist</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Zobrazenie</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápoveda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Stlač %1 pre zvýšenie hlasitosti, %2 pre jej zníženie</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otváram %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Aktualizácia kolekcie...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Aktualizácia kolekcie - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Kolekcia úspešne aktualizovaná</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Kritická chyba: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Chyba: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Opustiť &amp;Celú Obrazovku</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Zostávajúci čas: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Hlasitosť na %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Hlasitosť stlmená</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Hlasitosť nie je stlmená</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Získať plnú verziu</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 verzie %2 je práve dostupný.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Pripomenúť neskôr</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizovať</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizovať</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavrieť</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Zakúpiť %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Zastav po tejto skladbe</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Vedenie štatistík, skroblovanie</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>&amp;Odoslať prehraté skladby na %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Odhlásenie z %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Nahlásiť problém...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 ukončil skenovanie vašej hudobnej kolekcie</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Pusť sem skladby</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Koniec playlistu</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Ide o demoverziu %1</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Umožní ti prehrať niekoľko skladieb, takže môžeš aplikáciu vyskúšať a pohodlne otestovať.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračuj</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Získať plnú verziu</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Nová verzia %1 je práve dostupná!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 je práve dostupná. Máš %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Chceš ju stiahnuť?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Preskočiť túto verziu</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Pripomenúť mi neskôr</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Nainštalovať aktualizáciu</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Vložiť</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Demoverzia je limitovaná iba na %1 skladieb v playliste.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Prázdny playlist</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 skladieb - Celková dĺžka je %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Žiadne výsledky hľadania.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Skladieb</translation>
    </message>
</context>
</TS>